==> gr-howto-write-a-block-0.4.tar.gz: gr-howto-write-a-block-0.4/src/lib/howto.py <==
# This file was created automatically by SWIG 1.3.27.
# Don't modify this file, modify the SWIG interface instead.

import _howto

def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name) or (name == "thisown"):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


def _swig_setattr_nondynamic_method(set):
    def set_attr(self,name,value):
        if hasattr(self,name) or (name in ("this", "thisown")):
            set(self,name,value)
        else:
            raise AttributeError("You cannot add attributes to %s" % self)
    return set_attr


class howto_square_ff_sptr(object):
    """Proxy of C++ howto_square_ff_sptr class"""
    def __repr__(self):
        return "<%s.%s; proxy of C++ boost::shared_ptr<howto_square_ff > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    def __init__(self, *args):
        """
        __init__(self) -> howto_square_ff_sptr
        __init__(self,  p) -> howto_square_ff_sptr
        """
        newobj = _howto.new_howto_square_ff_sptr(*args)
        self.this = newobj.this
        self.thisown = 1
        del newobj.thisown
    def __deref__(*args):
        """__deref__(self)"""
        return _howto.howto_square_ff_sptr___deref__(*args)

    def name(*args):
        """name(self) -> string"""
        return _howto.howto_square_ff_sptr_name(*args)

    def input_signature(*args):
        """input_signature(self) -> gr_io_signature_sptr"""
        return _howto.howto_square_ff_sptr_input_signature(*args)

    def output_signature(*args):
        """output_signature(self) -> gr_io_signature_sptr"""
        return _howto.howto_square_ff_sptr_output_signature(*args)

    def unique_id(*args):
        """unique_id(self) -> long"""
        return _howto.howto_square_ff_sptr_unique_id(*args)

    def history(*args):
        """history(self) -> unsigned int"""
        return _howto.howto_square_ff_sptr_history(*args)

    def output_multiple(*args):
        """output_multiple(self) -> int"""
        return _howto.howto_square_ff_sptr_output_multiple(*args)

    def relative_rate(*args):
        """relative_rate(self) -> double"""
        return _howto.howto_square_ff_sptr_relative_rate(*args)

    def check_topology(*args):
        """check_topology(self, int ninputs, int noutputs) -> bool"""
        return _howto.howto_square_ff_sptr_check_topology(*args)

    def start(*args):
        """start(self) -> bool"""
        return _howto.howto_square_ff_sptr_start(*args)

    def stop(*args):
        """stop(self) -> bool"""
        return _howto.howto_square_ff_sptr_stop(*args)

    def detail(*args):
        """detail(self) -> gr_block_detail_sptr"""
        return _howto.howto_square_ff_sptr_detail(*args)

    def set_detail(*args):
        """set_detail(self, gr_block_detail_sptr detail)"""
        return _howto.howto_square_ff_sptr_set_detail(*args)

    def __del__(self, destroy=_howto.delete_howto_square_ff_sptr):
        """__del__(self)"""
        try:
            if self.thisown: destroy(self)
        except: pass


class howto_square_ff_sptrPtr(howto_square_ff_sptr):
    def __init__(self, this):
        self.this = this
        if not hasattr(self,"thisown"): self.thisown = 0
        self.__class__ = howto_square_ff_sptr
_howto.howto_square_ff_sptr_swigregister(howto_square_ff_sptrPtr)


def howto_square_ff_block(*args):
    """howto_square_ff_block(howto_square_ff_sptr r) -> gr_block_sptr"""
    return _howto.howto_square_ff_block(*args)
howto_square_ff_sptr.block = lambda self: howto_square_ff_block (self)
howto_square_ff_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


def square_ff(*args):
    """square_ff() -> howto_square_ff_sptr"""
    return _howto.square_ff(*args)
class howto_square2_ff_sptr(object):
    """Proxy of C++ howto_square2_ff_sptr class"""
    def __repr__(self):
        return "<%s.%s; proxy of C++ boost::shared_ptr<howto_square2_ff > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    def __init__(self, *args):
        """
        __init__(self) -> howto_square2_ff_sptr
        __init__(self,  p) -> howto_square2_ff_sptr
        """
        newobj = _howto.new_howto_square2_ff_sptr(*args)
        self.this = newobj.this
        self.thisown = 1
        del newobj.thisown
    def __deref__(*args):
        """__deref__(self)"""
        return _howto.howto_square2_ff_sptr___deref__(*args)

    def name(*args):
        """name(self) -> string"""
        return _howto.howto_square2_ff_sptr_name(*args)

    def input_signature(*args):
        """input_signature(self) -> gr_io_signature_sptr"""
        return _howto.howto_square2_ff_sptr_input_signature(*args)

    def output_signature(*args):
        """output_signature(self) -> gr_io_signature_sptr"""
        return _howto.howto_square2_ff_sptr_output_signature(*args)

    def unique_id(*args):
        """unique_id(self) -> long"""
        return _howto.howto_square2_ff_sptr_unique_id(*args)

    def history(*args):
        """history(self) -> unsigned int"""
        return _howto.howto_square2_ff_sptr_history(*args)

    def output_multiple(*args):
        """output_multiple(self) -> int"""
        return _howto.howto_square2_ff_sptr_output_multiple(*args)

    def relative_rate(*args):
        """relative_rate(self) -> double"""
        return _howto.howto_square2_ff_sptr_relative_rate(*args)

    def check_topology(*args):
        """check_topology(self, int ninputs, int noutputs) -> bool"""
        return _howto.howto_square2_ff_sptr_check_topology(*args)

    def start(*args):
        """start(self) -> bool"""
        return _howto.howto_square2_ff_sptr_start(*args)

    def stop(*args):
        """stop(self) -> bool"""
        return _howto.howto_square2_ff_sptr_stop(*args)

    def detail(*args):
        """detail(self) -> gr_block_detail_sptr"""
        return _howto.howto_square2_ff_sptr_detail(*args)

    def set_detail(*args):
        """set_detail(self, gr_block_detail_sptr detail)"""
        return _howto.howto_square2_ff_sptr_set_detail(*args)

    def __del__(self, destroy=_howto.delete_howto_square2_ff_sptr):
        """__del__(self)"""
        try:
            if self.thisown: destroy(self)
        except: pass


class howto_square2_ff_sptrPtr(howto_square2_ff_sptr):
    def __init__(self, this):
        self.this = this
        if not hasattr(self,"thisown"): self.thisown = 0
        self.__class__ = howto_square2_ff_sptr
_howto.howto_square2_ff_sptr_swigregister(howto_square2_ff_sptrPtr)


def howto_square2_ff_block(*args):
    """howto_square2_ff_block(howto_square2_ff_sptr r) -> gr_block_sptr"""
    return _howto.howto_square2_ff_block(*args)
howto_square2_ff_sptr.block = lambda self: howto_square2_ff_block (self)
howto_square2_ff_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


def square2_ff(*args):
    """square2_ff() -> howto_square2_ff_sptr"""
    return _howto.square2_ff(*args)

==> gr-howto-write-a-block-0.5.tar.gz: gr-howto-write-a-block-0.5/src/lib/howto.py <==
# This file was created automatically by SWIG 1.3.29.
# Don't modify this file, modify the SWIG interface instead.

import _howto
import new
new_instancemethod = new.instancemethod
def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "thisown"): return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'PySwigObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    if (name == "thisown"): return self.this.own()
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

def _swig_repr(self):
    try: strthis = "proxy of " + self.this.__repr__()
    except: strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


def _swig_setattr_nondynamic_method(set):
    def set_attr(self,name,value):
        if (name == "thisown"): return self.this.own(value)
        if hasattr(self,name) or (name == "this"):
            set(self,name,value)
        else:
            raise AttributeError("You cannot add attributes to %s" % self)
    return set_attr


class howto_square_ff_sptr(object):
    """Proxy of C++ howto_square_ff_sptr class"""
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr
    def __init__(self, *args): 
        """
        __init__(self) -> howto_square_ff_sptr
        __init__(self,  p) -> howto_square_ff_sptr
        """
        this = _howto.new_howto_square_ff_sptr(*args)
        try: self.this.append(this)
        except: self.this = this
    def __deref__(*args):
        """__deref__(self)"""
        return _howto.howto_square_ff_sptr___deref__(*args)

    __swig_destroy__ = _howto.delete_howto_square_ff_sptr
    __del__ = lambda self : None;
    def name(*args):
        """name(self) -> string"""
        return _howto.howto_square_ff_sptr_name(*args)

    def input_signature(*args):
        """input_signature(self) -> gr_io_signature_sptr"""
        return _howto.howto_square_ff_sptr_input_signature(*args)

    def output_signature(*args):
        """output_signature(self) -> gr_io_signature_sptr"""
        return _howto.howto_square_ff_sptr_output_signature(*args)

    def unique_id(*args):
        """unique_id(self) -> long"""
        return _howto.howto_square_ff_sptr_unique_id(*args)

    def history(*args):
        """history(self) -> unsigned int"""
        return _howto.howto_square_ff_sptr_history(*args)

    def output_multiple(*args):
        """output_multiple(self) -> int"""
        return _howto.howto_square_ff_sptr_output_multiple(*args)

    def relative_rate(*args):
        """relative_rate(self) -> double"""
        return _howto.howto_square_ff_sptr_relative_rate(*args)

    def check_topology(*args):
        """check_topology(self, int ninputs, int noutputs) -> bool"""
        return _howto.howto_square_ff_sptr_check_topology(*args)

    def start(*args):
        """start(self) -> bool"""
        return _howto.howto_square_ff_sptr_start(*args)

    def stop(*args):
        """stop(self) -> bool"""
        return _howto.howto_square_ff_sptr_stop(*args)

    def detail(*args):
        """detail(self) -> gr_block_detail_sptr"""
        return _howto.howto_square_ff_sptr_detail(*args)

    def set_detail(*args):
        """set_detail(self, gr_block_detail_sptr detail)"""
        return _howto.howto_square_ff_sptr_set_detail(*args)

howto_square_ff_sptr_swigregister = _howto.howto_square_ff_sptr_swigregister
howto_square_ff_sptr_swigregister(howto_square_ff_sptr)


def howto_square_ff_block(*args):
  """howto_square_ff_block(howto_square_ff_sptr r) -> gr_block_sptr"""
  return _howto.howto_square_ff_block(*args)
howto_square_ff_sptr.block = lambda self: howto_square_ff_block (self)
howto_square_ff_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


def square_ff(*args):
  """square_ff() -> howto_square_ff_sptr"""
  return _howto.square_ff(*args)
class howto_square2_ff_sptr(object):
    """Proxy of C++ howto_square2_ff_sptr class"""
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr
    def __init__(self, *args): 
        """
        __init__(self) -> howto_square2_ff_sptr
        __init__(self,  p) -> howto_square2_ff_sptr
        """
        this = _howto.new_howto_square2_ff_sptr(*args)
        try: self.this.append(this)
        except: self.this = this
    def __deref__(*args):
        """__deref__(self)"""
        return _howto.howto_square2_ff_sptr___deref__(*args)

    __swig_destroy__ = _howto.delete_howto_square2_ff_sptr
    __del__ = lambda self : None;
    def name(*args):
        """name(self) -> string"""
        return _howto.howto_square2_ff_sptr_name(*args)

    def input_signature(*args):
        """input_signature(self) -> gr_io_signature_sptr"""
        return _howto.howto_square2_ff_sptr_input_signature(*args)

    def output_signature(*args):
        """output_signature(self) -> gr_io_signature_sptr"""
        return _howto.howto_square2_ff_sptr_output_signature(*args)

    def unique_id(*args):
        """unique_id(self) -> long"""
        return _howto.howto_square2_ff_sptr_unique_id(*args)

    def history(*args):
        """history(self) -> unsigned int"""
        return _howto.howto_square2_ff_sptr_history(*args)

    def output_multiple(*args):
        """output_multiple(self) -> int"""
        return _howto.howto_square2_ff_sptr_output_multiple(*args)

    def relative_rate(*args):
        """relative_rate(self) -> double"""
        return _howto.howto_square2_ff_sptr_relative_rate(*args)

    def check_topology(*args):
        """check_topology(self, int ninputs, int noutputs) -> bool"""
        return _howto.howto_square2_ff_sptr_check_topology(*args)

    def start(*args):
        """start(self) -> bool"""
        return _howto.howto_square2_ff_sptr_start(*args)

    def stop(*args):
        """stop(self) -> bool"""
        return _howto.howto_square2_ff_sptr_stop(*args)

    def detail(*args):
        """detail(self) -> gr_block_detail_sptr"""
        return _howto.howto_square2_ff_sptr_detail(*args)

    def set_detail(*args):
        """set_detail(self, gr_block_detail_sptr detail)"""
        return _howto.howto_square2_ff_sptr_set_detail(*args)

howto_square2_ff_sptr_swigregister = _howto.howto_square2_ff_sptr_swigregister
howto_square2_ff_sptr_swigregister(howto_square2_ff_sptr)


def howto_square2_ff_block(*args):
  """howto_square2_ff_block(howto_square2_ff_sptr r) -> gr_block_sptr"""
  return _howto.howto_square2_ff_block(*args)
howto_square2_ff_sptr.block = lambda self: howto_square2_ff_block (self)
howto_square2_ff_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


def square2_ff(*args):
  """square2_ff() -> howto_square2_ff_sptr"""
  return _howto.square2_ff(*args)
